@@ -15,7 +15,10 @@
 #include <kio/simplejob.h>
 #include <kprotocolinfo.h>
 
+#ifdef WITH_QTDBUS
 #include <KDirNotify>
+#endif
+
 #include <KDirWatch>
 
 #include <QDebug>
@@ -24,8 +27,6 @@
 
 QTEST_MAIN(KDirListerTest)
 
-static constexpr bool s_workaroundBrokenInotify = false;
-
 GlobalInits::GlobalInits()
 {
     // Must be done before the QSignalSpys connect
@@ -44,7 +45,7 @@ void KDirListerTest::initTestCase()
     // To avoid failing on broken locally defined MIME types
     QStandardPaths::setTestModeEnabled(true);
 
-    m_tempDir.reset(new QTemporaryDir(homeTmpDir()));
+    m_tempDir.reset(new QTemporaryDir(tmpDirTemplate()));
 
     // No message dialogs
     KIO::setDefaultJobUiDelegateExtension(nullptr);
@@ -122,6 +123,7 @@ void KDirListerTest::testOpenUrl()
 
     // then wait for completed
     qDebug("waiting for completed");
+    QTRY_VERIFY(m_dirLister.isFinished());
     QTRY_COMPARE(m_dirLister.spyStarted.count(), 1);
     QTRY_COMPARE(m_dirLister.spyCompleted.count(), 1);
     QCOMPARE(m_dirLister.spyCompletedQUrl.count(), 1);
@@ -362,7 +364,7 @@ void KDirListerTest::testNewItemsInSymlink() // #213799
     const int origItemCount = m_items.count();
     QCOMPARE(fileCount(), origItemCount);
     const QString path = tempPath();
-    QTemporaryFile tempFile;
+    QTemporaryFile tempFile(tmpDirTemplate() + QStringLiteral("_normal_file"));
     QVERIFY(tempFile.open());
     const QString symPath = tempFile.fileName() + "_link";
     tempFile.close();
@@ -385,16 +387,12 @@ void KDirListerTest::testNewItemsInSymlink() // #213799
     QTRY_COMPARE(m_items.count(), origItemCount);
     QTRY_VERIFY(dirLister2.isFinished());
 
-    QTest::qWait(100); // We need a 1s timestamp difference on the dir, otherwise FAM won't notice anything.
+    QTest::qWait(1000); // We need a 1s timestamp difference on the dir, otherwise FAM won't notice anything.
 
     qDebug() << "Creating new file";
     const QString fileName = QStringLiteral("toplevelfile_newinlink");
     createSimpleFile(path + fileName);
 
-    if (s_workaroundBrokenInotify) {
-        org::kde::KDirNotify::emitFilesAdded(QUrl::fromLocalFile(path));
-    }
-
     // Give time for KDirWatch to notify us
     QTRY_COMPARE(m_items2.count(), origItemCount + 1);
     QTRY_COMPARE(m_items.count(), origItemCount + 1);
@@ -413,29 +411,34 @@ void KDirListerTest::testNewItemsInSymlink() // #213799
     // Test file deletion
     {
         qDebug() << "Deleting" << (path + fileName);
-        QTest::qWait(100); // for timestamp difference
+        QTest::qWait(1000); // for timestamp difference
         QFile::remove(path + fileName);
-        QTRY_COMPARE(dirLister2.spyItemsDeleted.count(), 1);
-        QTRY_COMPARE(m_dirLister.spyItemsDeleted.count(), 1);
+        QTRY_COMPARE_WITH_TIMEOUT(dirLister2.spyItemsDeleted.count(), 1, 1000);
+        QTRY_COMPARE_WITH_TIMEOUT(m_dirLister.spyItemsDeleted.count(), 1, 1000);
         const KFileItem item = dirLister2.spyItemsDeleted[0][0].value<KFileItemList>().at(0);
         QCOMPARE(item.url().toLocalFile(), QString(symPath + '/' + fileName));
+
+        dirLister2.spyItemsDeleted.clear();
+        m_dirLister.spyItemsDeleted.clear();
     }
     // Test file deletion in symlink dir #469254
     {
         qDebug() << "Deleting" << (symPath + "/" + fileName2);
-        QTest::qWait(100); // for timestamp difference
+        QTest::qWait(1000); // for timestamp difference
         QFile::remove(symPath + "/" + fileName2);
-        QTRY_COMPARE(dirLister2.spyItemsDeleted.count(), 2);
-        QTRY_COMPARE(m_dirLister.spyItemsDeleted.count(), 2);
-        const KFileItem item = dirLister2.spyItemsDeleted[1][0].value<KFileItemList>().at(0);
-        QCOMPARE(item.url().toLocalFile(), QString(symPath + '/' + fileName2));
+
+        QTRY_COMPARE_WITH_TIMEOUT(m_dirLister.spyItemsDeleted.count(), 1, 1000);
+        const KFileItem item = m_dirLister.spyItemsDeleted[0][0].value<KFileItemList>().at(0);
+        QCOMPARE(item.url().toLocalFile(), QString(path + fileName2));
+
+        QTRY_COMPARE_WITH_TIMEOUT(dirLister2.spyItemsDeleted.count(), 1, 1000);
+        const KFileItem item2 = dirLister2.spyItemsDeleted[0][0].value<KFileItemList>().at(0);
+        QCOMPARE(item2.url().toLocalFile(), QString(symPath + '/' + fileName2));
     }
-
-    // TODO: test file update.
-    disconnect(&m_dirLister, nullptr, this, nullptr);
-
     QFile::remove(symPath);
-    m_dirLister.openUrl(QUrl::fromLocalFile(tempPath()));
+
+    m_dirLister.spyItemsDeleted.clear();
+    dirLister2.spyItemsDeleted.clear();
 }
 
 // This test assumes testOpenUrl was run before. So m_dirLister is holding the items already.
@@ -487,6 +490,7 @@ void KDirListerTest::testRefreshItems()
 // Refresh the root item, plus a hidden file, e.g. changing its icon. #190535
 void KDirListerTest::testRefreshRootItem()
 {
+#ifdef WITH_QTDBUS
     // This test assumes testOpenUrl was run before. So m_dirLister is holding the items already.
     m_refreshedItems.clear();
     m_refreshedItems2.clear();
@@ -556,6 +560,7 @@ void KDirListerTest::testRefreshRootItem()
 
     // Note: this test leaves the .directory file as a side effect.
     // Hidden though, shouldn't matter.
+#endif
 }
 
 void KDirListerTest::testDeleteItem()
@@ -653,10 +658,6 @@ void KDirListerTest::testRenameAndOverwrite() // has to be run after testRenameI
     const QString path = dirPath + "toplevelfile_2";
     createTestFile(path);
 
-    if (s_workaroundBrokenInotify) {
-        org::kde::KDirNotify::emitFilesAdded(QUrl::fromLocalFile(dirPath));
-    }
-
     KFileItem existingItem;
     while (existingItem.isNull()) {
         QTest::qWait(100);
@@ -838,7 +839,7 @@ void KDirListerTest::testConcurrentListingAndStop()
     MyDirLister dirLister2;
 
     // Use a new tempdir for this test, so that we don't use the cache at all.
-    QTemporaryDir tempDir(homeTmpDir());
+    QTemporaryDir tempDir(tmpDirTemplate());
     const QString path = tempDir.path() + '/';
     createTestFile(path + "file_1");
     createTestFile(path + "file_2");
@@ -1030,7 +1031,7 @@ void KDirListerTest::testBug211472()
 {
     m_items.clear();
 
-    QTemporaryDir newDir(homeTmpDir());
+    QTemporaryDir newDir(tmpDirTemplate());
     const QString path = newDir.path() + "/newsubdir/";
     QDir().mkdir(path);
     MyDirLister dirLister;
@@ -1083,6 +1084,7 @@ void KDirListerTest::testBug211472()
 
 void KDirListerTest::testRenameCurrentDir() // #294445
 {
+#ifdef WITH_QTDBUS
     m_items.clear();
 
     const QString path = tempPath() + "newsubdir-1";
@@ -1108,6 +1110,7 @@ void KDirListerTest::testRenameCurrentDir() // #294445
 
     disconnect(&secondDirLister, nullptr, this, nullptr);
     QDir().rmdir(newPath);
+#endif
 }
 
 void KDirListerTest::slotOpenUrlOnRename(const QUrl &newUrl)
@@ -1120,6 +1123,7 @@ void KDirListerTest::slotOpenUrlOnRename(const QUrl &newUrl)
 // Matches usage in gwenview.
 void KDirListerTest::testRenameCurrentDirOpenUrl()
 {
+#ifdef WITH_QTDBUS
     m_items.clear();
     const QString path = tempPath() + "newsubdir-1/";
     QVERIFY(QDir().mkdir(path));
@@ -1145,6 +1149,7 @@ void KDirListerTest::testRenameCurrentDirOpenUrl()
     QTRY_VERIFY(m_dirLister.isFinished());
     disconnect(&m_dirLister, nullptr, this, nullptr);
     QDir().rmdir(newPath);
+#endif
 }
 
 void KDirListerTest::testRedirection()
@@ -1197,7 +1202,7 @@ void KDirListerTest::testListEmptyDirFromCache() // #278431
 {
     m_items.clear();
 
-    QTemporaryDir newDir(homeTmpDir());
+    QTemporaryDir newDir(tmpDirTemplate());
     const QUrl url = QUrl::fromLocalFile(newDir.path());
 
     // List and watch an empty dir
@@ -1233,7 +1238,7 @@ void KDirListerTest::testWatchingAfterCopyJob() // #331582
 {
     m_items.clear();
 
-    QTemporaryDir newDir(homeTmpDir());
+    QTemporaryDir newDir(tmpDirTemplate());
     const QString path = newDir.path() + '/';
 
     // List and watch an empty dir
@@ -1285,7 +1290,7 @@ void KDirListerTest::testRemoveWatchedDirectory()
 {
     m_items.clear();
 
-    QTemporaryDir newDir(homeTmpDir());
+    QTemporaryDir newDir(tmpDirTemplate());
     const QString path = newDir.path() + '/';
 
     // List and watch an empty dir
@@ -1326,12 +1331,16 @@ void KDirListerTest::testRemoveWatchedDirectory()
 
 void KDirListerTest::testDirPermissionChange()
 {
-    QTemporaryDir tempDir(homeTmpDir());
+    QTemporaryDir tempDir(tmpDirTemplate());
 
     const QString path = tempDir.path() + '/';
     const QString subdir = path + QLatin1String("subdir");
     QVERIFY(QDir().mkdir(subdir));
 
+    // ensure initial permissions are different to the ones we set below
+    const mode_t initPermissions = (S_IRUSR | S_IWUSR | S_IXUSR | S_IRGRP | S_IXGRP);
+    QVERIFY(KIO::chmod(QUrl::fromLocalFile(subdir), initPermissions)->exec());
+
     MyDirLister mylister;
     mylister.openUrl(QUrl::fromLocalFile(tempDir.path()));
     QSignalSpy spyCompleted(&mylister, qOverload<>(&KCoreDirLister::completed));
@@ -1447,23 +1456,27 @@ void KDirListerTest::testRenameDirectory() // #401552
         slotOpenUrlOnRename(newUrl);
     });
 
-    for (int i = 0; i < dirs.size(); i++) {
+    for (const auto &newDir : dirs) {
         // Wait for the listener to get all files
         QTRY_VERIFY(m_dirLister.isFinished());
         // Do the rename
-        QString newDir = dirs.at(i);
         job = KIO::rename(QUrl::fromLocalFile(currDir), QUrl::fromLocalFile(newDir), KIO::HideProgressInfo);
         QVERIFY2(job->exec(), qPrintable(job->errorString()));
         QTest::qWait(500); // Without the delay the crash doesn't happen
         currDir = newDir;
     }
+
+    // cleanup
+    const auto delJob = KIO::del(QUrl::fromLocalFile(dirs.last()));
+    QVERIFY(delJob->exec());
+
     disconnect(&m_dirLister, nullptr, this, nullptr);
 }
 
 void KDirListerTest::testRequestMimeType()
 {
     // Use a new tempdir and lister instance for this test, so that we don't use any cache at all.
-    QTemporaryDir tempDir(homeTmpDir());
+    QTemporaryDir tempDir(tmpDirTemplate());
     QString path = tempDir.path() + QLatin1Char('/');
 
     createTestFile(path + "/file_1");
@@ -1525,7 +1538,7 @@ void KDirListerTest::testMimeFilter_data()
 void KDirListerTest::testMimeFilter()
 {
     // Use a new tempdir and lister instance for this test, so that we don't use any cache at all.
-    QTemporaryDir tempDir(homeTmpDir());
+    QTemporaryDir tempDir(tmpDirTemplate());
     QString path = tempDir.path() + '/';
 
     QFETCH(QStringList, files);
@@ -1540,8 +1553,7 @@ void KDirListerTest::testMimeFilter()
     lister.setMimeFilter(mimeTypes);
     lister.openUrl(QUrl::fromLocalFile(path), KDirLister::NoFlags);
 
-    QSignalSpy spyCompleted(&lister, qOverload<>(&KCoreDirLister::completed));
-    QVERIFY(spyCompleted.wait(1000));
+    QVERIFY(lister.spyCompleted.wait(1000));
 
     QCOMPARE(lister.items().size(), filteredFiles.size());
 
@@ -1555,6 +1567,9 @@ void KDirListerTest::testDeleteCurrentDir()
 {
     // ensure m_dirLister holds the items.
     m_dirLister.openUrl(QUrl::fromLocalFile(tempPath()), KDirLister::NoFlags);
+
+    QVERIFY(m_dirLister.spyCompleted.wait(1000));
+
     m_dirLister.clearSpies();
     KIO::DeleteJob *job = KIO::del(QUrl::fromLocalFile(tempPath()), KIO::HideProgressInfo);
     bool ok = job->exec();
@@ -1563,19 +1578,16 @@ void KDirListerTest::testDeleteCurrentDir()
 
     QCOMPARE(m_dirLister.spyClearDir.count(), 0);
 
-    QList<QUrl> deletedUrls;
-    for (int i = 0; i < m_dirLister.spyItemsDeleted.count(); ++i) {
-        deletedUrls += m_dirLister.spyItemsDeleted[i][0].value<KFileItemList>().urlList();
-    }
-    // qDebug() << deletedUrls;
+    QCOMPARE(m_dirLister.spyItemsDeleted.count(), 1);
+    const KFileItem deletedItem = m_dirLister.spyItemsDeleted.at(0).at(0).value<KFileItemList>().at(0);
+
     QUrl currentDirUrl = QUrl::fromLocalFile(tempPath()).adjusted(QUrl::StripTrailingSlash);
-    // Sometimes I get ("current/subdir", "current") here, but that seems ok.
-    QVERIFY(deletedUrls.contains(currentDirUrl));
+    QCOMPARE(currentDirUrl, deletedItem.url());
 }
 
 void KDirListerTest::testForgetDir()
 {
-    QTemporaryDir tempDir(homeTmpDir());
+    QTemporaryDir tempDir(tmpDirTemplate());
     QString path = tempDir.path();
     createTestFile(path + "/file_1");
 
@@ -1645,7 +1657,7 @@ void KDirListerTest::waitUntilAfter(const QDateTime &ctime)
 // and stop watching a directory because a separate lister left a directory open in another lister
 void KDirListerTest::testBug386763()
 {
-    QTemporaryDir newDir(homeTmpDir());
+    QTemporaryDir newDir(tmpDirTemplate());
     const QString path = newDir.path() + "/newsubdir/";
     const QString otherpath = newDir.path() + "/othersubdir/";
 
@@ -1684,7 +1696,7 @@ void KDirListerTest::testBug386763()
 
 void KDirListerTest::testCacheEviction()
 {
-    QTemporaryDir newDir(homeTmpDir());
+    QTemporaryDir newDir(tmpDirTemplate());
 
     MyDirLister dirLister;
     dirLister.openUrl(QUrl::fromLocalFile(newDir.path()));
