@@ -14,7 +14,6 @@
 
 namespace KIO
 {
-
 class FileCopyJobPrivate;
 /**
  * @class KIO::FileCopyJob filecopyjob.h <KIO/FileCopyJob>
@@ -39,7 +38,7 @@ public:
     /**
      * Sets the modification time of the file
      *
-     * Note that this is ignored if a direct copy (SlaveBase::copy) can be done,
+     * Note that this is ignored if a direct copy (WorkerBase::copy) can be done,
      * in which case the mtime of the source is applied to the destination (if the protocol
      * supports the concept).
      */
@@ -63,16 +62,17 @@ public:
 
 Q_SIGNALS:
     /**
-     * Mimetype determined during a file copy.
+     * MIME type determined during a file copy.
      * This is never emitted during a move, and might not be emitted during
-     * a file copy, depending on the slave. But when a get and a put are
+     * a file copy, depending on the worker. But when a get and a put are
      * being used (which is the common case), this signal forwards the
-     * mimetype information from the get job.
+     * MIME type information from the get job.
      *
      * @param job the job that emitted this signal
-     * @param type the mime type
+     * @param mimeType the MIME type
+     * @since 5.78
      */
-    void mimetype(KIO::Job *job, const QString &type);
+    void mimeTypeFound(KIO::Job *job, const QString &mimeType);
 
 protected Q_SLOTS:
     /**
@@ -82,7 +82,7 @@ protected Q_SLOTS:
     void slotResult(KJob *job) override;
 
 protected:
-    FileCopyJob(FileCopyJobPrivate &dd);
+    KIOCORE_NO_EXPORT explicit FileCopyJob(FileCopyJobPrivate &dd);
 
 private:
     Q_DECLARE_PRIVATE(FileCopyJob)
@@ -91,46 +91,52 @@ private:
 /**
  * Copy a single file.
  *
- * Uses either SlaveBase::copy() if the slave supports that
+ * Uses either WorkerBase::copy() if the worker supports that
  * or get() and put() otherwise.
- * @param src Where to get the file.
- * @param dest Where to put the file.
- * @param permissions May be -1. In this case no special permission mode is set.
- * @param flags Can be HideProgressInfo, Overwrite and Resume here. WARNING:
- * Setting Resume means that the data will be appended to @p dest if @p dest exists.
- * @return the job handling the operation.
+ *
+ * @param src Where to get the file
+ * @param dest Where to put the file
+ * @param permissions the file mode permissions to set on @p dest; if this is -1
+ * (the default) no special permissions will be set on @p dest, i.e. it'll have
+ * the default system permissions for newly created files, and the owner and group
+ * permissions are not preserved.
+ * @param flags Can be @ref JobFlag::HideProgressInfo, Overwrite and Resume here
+ * WARNING: Setting @ref JobFlag::Resume means that the data will be appended to
+ * @p dest if @p dest exists
+ * @return the job handling the operation
  */
-KIOCORE_EXPORT FileCopyJob *file_copy(const QUrl &src, const QUrl &dest, int permissions = -1,
-                                      JobFlags flags = DefaultFlags);
+KIOCORE_EXPORT FileCopyJob *file_copy(const QUrl &src, const QUrl &dest, int permissions = -1, JobFlags flags = DefaultFlags);
 
 /**
  * Overload for catching code mistakes. Do NOT call this method (it is not implemented),
  * insert a value for permissions (-1 by default) before the JobFlags.
- * @since 4.5
  */
-FileCopyJob *file_copy(const QUrl &src, const QUrl &dest, JobFlags flags) Q_DECL_EQ_DELETE;   // not implemented - on purpose.
+FileCopyJob *file_copy(const QUrl &src, const QUrl &dest, JobFlags flags) Q_DECL_EQ_DELETE; // not implemented - on purpose.
 
 /**
  * Move a single file.
  *
- * Use either SlaveBase::rename() if the slave supports that,
+ * Use either WorkerBase::rename() if the worker supports that,
  * or copy() and del() otherwise, or eventually get() & put() & del()
- * @param src Where to get the file.
- * @param dest Where to put the file.
- * @param permissions May be -1. In this case no special permission mode is set.
- * @param flags Can be HideProgressInfo, Overwrite and Resume here. WARNING:
- * Setting Resume means that the data will be appended to @p dest if @p dest exists.
- * @return the job handling the operation.
+ *
+ * @param src Where to get the file
+ * @param dest Where to put the file
+ * @param permissions the file mode permissions to set on @p dest; if this is -1
+ * (the default), no special permissions are set on @p dest, i.e. it'll have
+ * the default system permissions for newly created files, and the owner and group
+ * permissions are not preserved.
+ * @param flags Can be HideProgressInfo, Overwrite and Resume here
+ * WARNING: Setting @ref JobFlag::Resume means that the data will be appended to
+ * @p dest if @p dest exists
+ * @return the job handling the operation
  */
-KIOCORE_EXPORT FileCopyJob *file_move(const QUrl &src, const QUrl &dest, int permissions = -1,
-                                      JobFlags flags = DefaultFlags);
+KIOCORE_EXPORT FileCopyJob *file_move(const QUrl &src, const QUrl &dest, int permissions = -1, JobFlags flags = DefaultFlags);
 
 /**
  * Overload for catching code mistakes. Do NOT call this method (it is not implemented),
  * insert a value for permissions (-1 by default) before the JobFlags.
- * @since 4.3
  */
-FileCopyJob *file_move(const QUrl &src, const QUrl &dest, JobFlags flags) Q_DECL_EQ_DELETE;   // not implemented - on purpose.
+FileCopyJob *file_move(const QUrl &src, const QUrl &dest, JobFlags flags) Q_DECL_EQ_DELETE; // not implemented - on purpose.
 
 }
 
