@@ -227,13 +227,6 @@ public:
      */
     void redirection(const QUrl &_url);
 
-    /**
-     * Tell that we will only get an error page here.
-     * This means: the data you'll get isn't the data you requested,
-     * but an error page (usually HTML) that describes an error.
-     */
-    void errorPage();
-
     /**
      * Call this in mimetype() and in get(), when you know the MIME type.
      * See mimetype() about other ways to implement it.
