@@ -7,12 +7,24 @@
 #ifndef WORKERBASE_H
 #define WORKERBASE_H
 
+// lib
+#include "global.h"
+#include "job_base.h" // for KIO::JobFlags
+#include "udsentry.h"
+// Qt
+#include <QByteArray>
+// Std
 #include <memory>
 
-#include "slavebase.h" // for KIO::JobFlags
+class KConfigGroup;
+class KRemoteEncoding;
+
+class QHostInfo;
 
 namespace KIO
 {
+class AuthInfo;
+
 class WorkerBasePrivate;
 class WorkerResultPrivate;
 
@@ -44,7 +56,7 @@ public:
     Q_REQUIRED_RESULT static WorkerResult pass();
 
 private:
-    explicit WorkerResult(std::unique_ptr<WorkerResultPrivate> &&dptr);
+    KIOCORE_NO_EXPORT explicit WorkerResult(std::unique_ptr<WorkerResultPrivate> &&dptr);
     std::unique_ptr<WorkerResultPrivate> d;
 };
 
@@ -103,15 +115,6 @@ public:
      */
     void dataReq();
 
-#if KIOCORE_ENABLE_DEPRECATED_SINCE(5, 103)
-    /**
-     * Call to signal that data from the sub-URL is needed
-     * @deprecated Since 5.96, feature no longer exists.
-     */
-    KIOCORE_DEPRECATED_VERSION_BELATED(5, 103, 5, 96, "Feature no longer exists.")
-    void needSubUrlData();
-#endif
-
     /**
      * Used to report the status of the worker.
      * @param host the worker is currently connected to. (Should be
@@ -185,12 +188,17 @@ public:
      */
     void redirection(const QUrl &_url);
 
+#if KIOCORE_ENABLE_DEPRECATED_SINCE(6, 3)
     /**
      * Tell that we will only get an error page here.
      * This means: the data you'll get isn't the data you requested,
      * but an error page (usually HTML) that describes an error.
+     *
+     * @deprecated since 6.3, not implemented/used
      */
+    KIOCORE_DEPRECATED_VERSION(6, 3, "Not implemented/used")
     void errorPage();
+#endif
 
     /**
      * Call this in mimetype() and in get(), when you know the MIME type.
@@ -218,17 +226,9 @@ public:
         WarningContinueCancel = 3,
         WarningTwoActionsCancel = 4, ///< @since 5.100
         Information = 5,
-        SSLMessageBox = 6,
-        // In KMessageBox::DialogType; Sorry = 7, Error = 8, QuestionTwoActionsCancel = 9
+        // In KMessageBox::DialogType; <unused> = 7, Error = 8,
+        // QuestionTwoActionsCancel = 9
         WarningContinueCancelDetailed = 10,
-#if KIOCORE_ENABLE_DEPRECATED_SINCE(5, 100)
-        QuestionYesNo ///< @deprecated Since 5.100, use QuestionTwoActions.
-            KIOCORE_ENUMERATOR_DEPRECATED_VERSION(5, 100, "Use QuestionTwoActions.") = QuestionTwoActions,
-        WarningYesNo ///< @deprecated Since 5.100, use WarningTwoActions.
-            KIOCORE_ENUMERATOR_DEPRECATED_VERSION(5, 100, "Use WarningTwoActions.") = WarningTwoActions,
-        WarningYesNoCancel ///< @deprecated Since 5.100, use WarningTwoActionsCancel.
-            KIOCORE_ENUMERATOR_DEPRECATED_VERSION(5, 100, "Use WarningTwoActionsCancel.") = WarningTwoActionsCancel,
-#endif
     };
 
     /**
@@ -240,12 +240,6 @@ public:
         PrimaryAction = 3, ///< @since 5.100
         SecondaryAction = 4, ///< @since 5.100
         Continue = 5,
-#if KIOCORE_ENABLE_DEPRECATED_SINCE(5, 100)
-        Yes ///< @deprecated Since 5.100, use PrimaryAction.
-            KIOCORE_ENUMERATOR_DEPRECATED_VERSION(5, 100, "Use PrimaryAction.") = PrimaryAction,
-        No ///< @deprecated Since 5.100, use SecondaryAction.
-            KIOCORE_ENUMERATOR_DEPRECATED_VERSION(5, 100, "Use SecondaryAction.") = SecondaryAction,
-#endif
     };
 
     /**
@@ -254,12 +248,10 @@ public:
      * @param text Message string. May contain newlines.
      * @param title Message box title.
      * @param primaryActionText the text for the first button.
-     *                          Ignored for @p type Information & SSLMessageBox.
-     *                          The (deprecated since 5.100) default is i18n("&Yes").
+     *                          Ignored for @p type Information.
      * @param secondaryActionText the text for the second button.
      *                            Ignored for @p type WarningContinueCancel, WarningContinueCancelDetailed,
-     *                            Information & SSLMessageBox.
-     *                            The (deprecated since 5.100) default is i18n("&No").
+     *                            Information.
      * @return a button code, as defined in ButtonCode, or 0 on communication error.
      */
     int messageBox(MessageBoxType type,
@@ -274,12 +266,10 @@ public:
      * @param type type of message box
      * @param title Message box title.
      * @param primaryActionText the text for the first button.
-     *                          Ignored for @p type Information & SSLMessageBox.
-     *                          The (deprecated since 5.100) default is i18n("&Yes").
+     *                          Ignored for @p type Information.
      * @param secondaryActionText the text for the second button.
      *                            Ignored for @p type WarningContinueCancel, WarningContinueCancelDetailed,
-     *                            Information & SSLMessageBox.
-     *                            The (deprecated since 5.100) default is i18n("&No").
+     *                            Information.
      * @param dontAskAgainName the name used to store result from 'Do not ask again' checkbox.
      * @return a button code, as defined in ButtonCode, or 0 on communication error.
      */
@@ -290,6 +280,8 @@ public:
                    const QString &secondaryActionText = QString(),
                    const QString &dontAskAgainName = QString());
 
+    int sslError(const QVariantMap &sslData);
+
     /**
      * Sets meta-data to be send to the application before the first
      * data() or finished() signal.
@@ -308,7 +300,7 @@ public:
     QString metaData(const QString &key) const;
 
     /**
-     * @internal for ForwardingSlaveBase
+     * @internal for ForwardingWorkerBase
      * Contains all metadata (but no config) sent by the application to the worker.
      */
     MetaData allMetaData() const;
@@ -636,15 +628,6 @@ public:
      */
     Q_REQUIRED_RESULT virtual WorkerResult special(const QByteArray &data);
 
-    /**
-     * Used for multiple get. Currently only used for HTTP pipelining
-     * support.
-     *
-     * @param data packed data; Contains number of URLs to fetch, and for
-     * each URL the URL itself and its associated MetaData.
-     */
-    Q_REQUIRED_RESULT virtual WorkerResult multiGet(const QByteArray &data);
-
     /**
      * Get a filesystem's total and available space.
      *
@@ -916,3 +899,27 @@ private:
 } // namespace KIO
 
 #endif
+
+// HACK while SlaveBase is still around:
+// Separate include/declaration guard matching the one in slavebase.h
+// around the same declaration of unsupportedActionErrorString()
+// Avoids consumers to need to include slavebase.h, while implementation
+// is still in slavebase.cpp for dependency reasons
+#ifndef KIO_UNSUPPORTEDACTIONERRORSTRING
+#define KIO_UNSUPPORTEDACTIONERRORSTRING
+
+namespace KIO
+{
+
+/**
+ * Returns an appropriate error message if the given command @p cmd
+ * is an unsupported action (ERR_UNSUPPORTED_ACTION).
+ * @param protocol name of the protocol
+ * @param cmd given command
+ * @see enum Command
+ */
+KIOCORE_EXPORT QString unsupportedActionErrorString(const QString &protocol, int cmd);
+
+} // namespace KIO
+
+#endif
