@@ -34,7 +34,8 @@
 #include <KMessageBox>
 #include <KProtocolManager>
 #include <KSharedConfig>
-#include <KStandardAction>
+#include <KStandardActions>
+#include <KToggleAction>
 #include <KUrlMimeData>
 #include <kfileitemdelegate.h>
 #include <kfilepreviewgenerator.h>
@@ -1294,6 +1295,19 @@ bool KDirOperator::eventFilter(QObject *watched, QEvent *event)
         }
         break;
     }
+    case QEvent::HoverLeave: {
+        if (d->m_preview && !d->m_preview->isHidden()) {
+            const QModelIndex currentIndex = d->m_itemView->selectionModel() ? d->m_itemView->selectionModel()->currentIndex() : QModelIndex();
+
+            if (currentIndex.isValid() && d->m_itemView->selectionModel()->isSelected(currentIndex)) {
+                const KFileItem item = d->m_itemView->model()->data(currentIndex, KDirModel::FileItemRole).value<KFileItem>();
+                if (!item.isNull()) {
+                    d->m_preview->showPreview(item.url());
+                }
+            }
+        }
+        break;
+    }
     case QEvent::Wheel: {
         QWheelEvent *evt = static_cast<QWheelEvent *>(event);
         if (evt->modifiers() & Qt::ControlModifier) {
@@ -1930,38 +1944,38 @@ void KDirOperator::setupActions()
     d->m_actionMenu = new KActionMenu(i18n("Menu"), this);
     d->m_actions[PopupMenu] = d->m_actionMenu;
 
-    QAction *upAction = KStandardAction::create(KStandardAction::Up, this, SLOT(cdUp()), this);
+    QAction *upAction = KStandardActions::create(KStandardActions::Up, this, &KDirOperator::cdUp, this);
     d->m_actions[Up] = upAction;
     upAction->setText(i18n("Parent Folder"));
 
-    QAction *backAction = KStandardAction::create(KStandardAction::Back, this, SLOT(back()), this);
+    QAction *backAction = KStandardActions::create(KStandardActions::Back, this, &KDirOperator::back, this);
     d->m_actions[Back] = backAction;
     auto backShortcuts = backAction->shortcuts();
     backShortcuts << Qt::Key_Backspace;
     backAction->setShortcuts(backShortcuts);
     backAction->setToolTip(i18nc("@info", "Go back"));
 
-    QAction *forwardAction = KStandardAction::create(KStandardAction::Forward, this, SLOT(forward()), this);
+    QAction *forwardAction = KStandardActions::create(KStandardActions::Forward, this, &KDirOperator::forward, this);
     d->m_actions[Forward] = forwardAction;
     forwardAction->setToolTip(i18nc("@info", "Go forward"));
 
-    QAction *homeAction = KStandardAction::create(KStandardAction::Home, this, SLOT(home()), this);
+    QAction *homeAction = KStandardActions::create(KStandardActions::Home, this, &KDirOperator::home, this);
     d->m_actions[Home] = homeAction;
     homeAction->setText(i18n("Home Folder"));
 
-    QAction *reloadAction = KStandardAction::create(KStandardAction::Redisplay, this, SLOT(rereadDir()), this);
+    QAction *reloadAction = KStandardActions::create(KStandardActions::Redisplay, this, &KDirOperator::rereadDir, this);
     d->m_actions[Reload] = reloadAction;
     reloadAction->setText(i18n("Reload"));
     reloadAction->setShortcuts(KStandardShortcut::shortcut(KStandardShortcut::Reload));
 
-    QAction *mkdirAction = new QAction(i18n("New Folder..."), this);
+    auto *mkdirAction = new QAction(i18nc("@action", "New Folder…"), this);
     d->m_actions[NewFolder] = mkdirAction;
     mkdirAction->setIcon(QIcon::fromTheme(QStringLiteral("folder-new")));
     connect(mkdirAction, &QAction::triggered, this, [this]() {
         mkdir();
     });
 
-    QAction *rename = KStandardAction::renameFile(this, &KDirOperator::renameSelected, this);
+    QAction *rename = KStandardActions::renameFile(this, &KDirOperator::renameSelected, this);
     d->m_actions[Rename] = rename;
 
     QAction *trash = new QAction(i18n("Move to Trash"), this);
@@ -2446,7 +2460,11 @@ void KDirOperatorPrivate::writeIconZoomSettingsIfNeeded()
     // must match behavior of iconSizeForViewType
     if (m_configGroup && m_itemView) {
         ZoomSettingsForView zoomSettings = zoomSettingsForView();
-        m_configGroup->writeEntry(zoomSettings.name, m_iconSize);
+        if ((m_iconSize == zoomSettings.defaultValue) && !m_configGroup->hasDefault(zoomSettings.name)) {
+            m_configGroup->revertToDefault(zoomSettings.name);
+        } else {
+            m_configGroup->writeEntry(zoomSettings.name, m_iconSize);
+        }
     }
 }
 
@@ -2832,16 +2850,13 @@ KDirOperatorPrivate::ZoomSettingsForView KDirOperatorPrivate::zoomSettingsForVie
 {
     KFile::FileView fv = static_cast<KFile::FileView>(m_viewKind);
 
-    KSharedConfigPtr config = KSharedConfig::openConfig();
     if (KFile::isSimpleView(fv)) {
-        KConfigGroup cg(config, QStringLiteral("DesktopIcons"));
-        const int desktopIconSize = cg.readEntry("Size", static_cast<int>(KIconLoader::SizeHuge));
         if (m_decorationPosition == QStyleOptionViewItem::Top) {
             // Simple view decoration above, aka Icons View
-            return {QStringLiteral("iconViewIconSize"), desktopIconSize};
+            return {QStringLiteral("iconViewIconSize"), static_cast<int>(KIconLoader::SizeHuge)};
         } else {
             // Simple view decoration left, aka compact view
-            return {QStringLiteral("listViewIconSize"), desktopIconSize};
+            return {QStringLiteral("listViewIconSize"), static_cast<int>(KIconLoader::SizeHuge)};
         }
     }
 
