@@ -99,7 +99,11 @@ public:
      * @see setOperationMode
      * @see operationMode
      */
-    enum OperationMode { Other = 0, Opening, Saving };
+    enum OperationMode {
+        Other = 0,
+        Opening,
+        Saving
+    };
 
     /**
      * @returns The selected fully qualified filename.
@@ -218,9 +222,9 @@ public:
 
     /**
      * Returns the current filter as entered by the user or one of the
-     * predefined set via setFilter().
+     * predefined set via setFilters().
      *
-     * @see setFilter()
+     * @see setFilters()
      * @see filterChanged()
      *
      * @since 6.0
@@ -475,12 +479,12 @@ Q_SIGNALS:
 
     /**
      * Emitted when the filter changed, i.e.\ the user entered an own filter
-     * or chose one of the predefined set via setFilter().
+     * or chose one of the predefined set via setFilters().
      *
      * @param filter contains the new filter (only the extension part,
      * not the explanation), i.e. "*.cpp" or "*.cpp *.cc".
      *
-     * @see setFilter()
+     * @see setFilters()
      * @see currentFilter()
      *
      * @since 6.0
@@ -499,11 +503,16 @@ public:
      */
     KDirOperator *dirOperator();
 
+#if KIOFILEWIDGETS_ENABLE_DEPRECATED_SINCE(6, 3)
     /**
      * reads the configuration for this widget from the given config group
      * @param group the KConfigGroup to read from
+     *
+     * @deprecated since 6.3, no known use case.
      */
+    KIOFILEWIDGETS_DEPRECATED_VERSION(6, 3, "No known use case")
     void readConfig(KConfigGroup &group);
+#endif
 
 private:
     friend class KFileWidgetPrivate;
