@@ -156,7 +156,13 @@ public:
     int currentDeviceId = 0;
     // Device ID for each file. Stored while in STATE_DEVICE_INFO state, used later on.
     QMap<QString, int> deviceIdMap;
-    enum CachePolicy { Prevent, Allow, Unknown } currentDeviceCachePolicy = Unknown;
+    enum CachePolicy {
+        Prevent,
+        Allow,
+        Unknown
+    } currentDeviceCachePolicy = Unknown;
+    // the path of a unique temporary directory
+    QString m_tempDirPath;
 
     void getOrCreateThumbnail();
     bool statResultThumbnail();
@@ -250,6 +256,9 @@ public:
         }
         return standardThumbs;
     }
+
+private:
+    QDir createTemporaryDir();
 };
 
 void PreviewJob::setDefaultDevicePixelRatio(qreal defaultDevicePixelRatio)
@@ -279,8 +288,12 @@ PreviewJob::PreviewJob(const KFileItemList &items, const QSize &size, const QStr
 
 PreviewJob::~PreviewJob()
 {
-#if WITH_SHM
     Q_D(PreviewJob);
+    if (!d->m_tempDirPath.isEmpty()) {
+        QDir tempDir(d->m_tempDirPath);
+        tempDir.removeRecursively();
+    }
+#if WITH_SHM
     if (d->shmaddr) {
         shmdt((char *)d->shmaddr);
         shmctl(d->shmid, IPC_RMID, nullptr);
@@ -798,13 +811,26 @@ int PreviewJobPrivate::getDeviceId(const QString &path)
     return idUnknown;
 }
 
+QDir KIO::PreviewJobPrivate::createTemporaryDir()
+{
+    if (m_tempDirPath.isEmpty()) {
+        auto tempDir = QTemporaryDir();
+        Q_ASSERT(tempDir.isValid());
+
+        tempDir.setAutoRemove(false);
+        // restrict read access to current User
+        QFile::setPermissions(tempDir.path(), QFile::Permission::ReadOwner | QFile::Permission::WriteOwner | QFile::Permission::ExeOwner);
+
+        m_tempDirPath = tempDir.path();
+    }
+
+    return QDir(m_tempDirPath);
+}
+
 void PreviewJobPrivate::createThumbnail(const QString &pixPath)
 {
     Q_Q(PreviewJob);
     state = PreviewJobPrivate::STATE_CREATETHUMB;
-    QUrl thumbURL;
-    thumbURL.setScheme(QStringLiteral("thumbnail"));
-    thumbURL.setPath(pixPath);
 
     bool save = bSave && currentItem.plugin.value(QStringLiteral("CacheThumbnail"), true) && !sequenceIndex;
 
@@ -816,8 +842,7 @@ void PreviewJobPrivate::createThumbnail(const QString &pixPath)
         return;
     }
 
-    // If caching is off, thumbPath is empty. Then we can't use standard thumbnailers.
-    if (currentItem.standardThumbnailer && !thumbPath.isEmpty()) {
+    if (currentItem.standardThumbnailer) {
         // Using /usr/share/thumbnailers
         QString exec;
         for (const auto &thumbnailer : standardThumbnailers().asKeyValueRange()) {
@@ -831,74 +856,74 @@ void PreviewJobPrivate::createThumbnail(const QString &pixPath)
             qCWarning(KIO_GUI) << "The exec entry for standard thumbnailer " << currentItem.plugin.name() << " was empty!";
             return;
         }
-
-        // Thumbnailer binaries only save and load files, so they can't be loaded directly into memory
-        const QString tempPath = thumbPath + QStringLiteral("/tmp/");
-        if (!QDir().exists(tempPath)) {
-            QDir().mkpath(tempPath);
+        auto tempDir = createTemporaryDir();
+        if (pixPath.startsWith(tempDir.path())) {
+            // don't generate thumbnails for images already in temporary directory
+            return;
         }
-        const QString tempOutputPath = tempPath + thumbName;
 
-        KIO::StandardThumbnailJob *job = new KIO::StandardThumbnailJob(exec, width * devicePixelRatio, currentItem.item.localPath(), tempOutputPath);
+        KIO::StandardThumbnailJob *job = new KIO::StandardThumbnailJob(exec, width * devicePixelRatio, pixPath, tempDir.path());
         q->addSubjob(job);
         q->connect(job, &KIO::StandardThumbnailJob::data, q, [=, this](KIO::Job *job, const QImage &thumb) {
             slotStandardThumbData(job, thumb);
-            // Delete the tmp file
-            QFile::remove(tempOutputPath);
         });
+        job->start();
+        return;
+    }
 
-    } else {
-        // Using thumbnailer plugin
-        KIO::TransferJob *job = KIO::get(thumbURL, NoReload, HideProgressInfo);
-        q->addSubjob(job);
-        q->connect(job, &KIO::TransferJob::data, q, [this](KIO::Job *job, const QByteArray &data) {
-            slotThumbData(job, data);
-        });
-        int thumb_width = width;
-        int thumb_height = height;
-        if (save) {
-            thumb_width = thumb_height = cacheSize;
-        }
+    // Using thumbnailer plugin
+    QUrl thumbURL;
+    thumbURL.setScheme(QStringLiteral("thumbnail"));
+    thumbURL.setPath(pixPath);
+    KIO::TransferJob *job = KIO::get(thumbURL, NoReload, HideProgressInfo);
+    q->addSubjob(job);
+    q->connect(job, &KIO::TransferJob::data, q, [this](KIO::Job *job, const QByteArray &data) {
+        slotThumbData(job, data);
+    });
+    int thumb_width = width;
+    int thumb_height = height;
+    if (save) {
+        thumb_width = thumb_height = cacheSize;
+    }
 
-        job->addMetaData(QStringLiteral("mimeType"), currentItem.item.mimetype());
-        job->addMetaData(QStringLiteral("width"), QString::number(thumb_width));
-        job->addMetaData(QStringLiteral("height"), QString::number(thumb_height));
-        job->addMetaData(QStringLiteral("plugin"), currentItem.plugin.fileName());
-        job->addMetaData(QStringLiteral("enabledPlugins"), enabledPlugins.join(QLatin1Char(',')));
-        job->addMetaData(QStringLiteral("devicePixelRatio"), QString::number(devicePixelRatio));
-        job->addMetaData(QStringLiteral("cache"), QString::number(cachePolicy == CachePolicy::Allow));
-        if (sequenceIndex) {
-            job->addMetaData(QStringLiteral("sequence-index"), QString::number(sequenceIndex));
-        }
+    job->addMetaData(QStringLiteral("mimeType"), currentItem.item.mimetype());
+    job->addMetaData(QStringLiteral("width"), QString::number(thumb_width));
+    job->addMetaData(QStringLiteral("height"), QString::number(thumb_height));
+    job->addMetaData(QStringLiteral("plugin"), currentItem.plugin.fileName());
+    job->addMetaData(QStringLiteral("enabledPlugins"), enabledPlugins.join(QLatin1Char(',')));
+    job->addMetaData(QStringLiteral("devicePixelRatio"), QString::number(devicePixelRatio));
+    job->addMetaData(QStringLiteral("cache"), QString::number(cachePolicy == CachePolicy::Allow));
+    if (sequenceIndex) {
+        job->addMetaData(QStringLiteral("sequence-index"), QString::number(sequenceIndex));
+    }
 
 #if WITH_SHM
-        size_t requiredSize = thumb_width * devicePixelRatio * thumb_height * devicePixelRatio * 4;
-        if (shmid == -1 || shmsize < requiredSize) {
-            if (shmaddr) {
-                // clean previous shared memory segment
-                shmdt((char *)shmaddr);
-                shmaddr = nullptr;
-                shmctl(shmid, IPC_RMID, nullptr);
-                shmid = -1;
-            }
-            if (requiredSize > 0) {
-                shmid = shmget(IPC_PRIVATE, requiredSize, IPC_CREAT | 0600);
-                if (shmid != -1) {
-                    shmsize = requiredSize;
-                    shmaddr = (uchar *)(shmat(shmid, nullptr, SHM_RDONLY));
-                    if (shmaddr == (uchar *)-1) {
-                        shmctl(shmid, IPC_RMID, nullptr);
-                        shmaddr = nullptr;
-                        shmid = -1;
-                    }
+    size_t requiredSize = thumb_width * devicePixelRatio * thumb_height * devicePixelRatio * 4;
+    if (shmid == -1 || shmsize < requiredSize) {
+        if (shmaddr) {
+            // clean previous shared memory segment
+            shmdt((char *)shmaddr);
+            shmaddr = nullptr;
+            shmctl(shmid, IPC_RMID, nullptr);
+            shmid = -1;
+        }
+        if (requiredSize > 0) {
+            shmid = shmget(IPC_PRIVATE, requiredSize, IPC_CREAT | 0600);
+            if (shmid != -1) {
+                shmsize = requiredSize;
+                shmaddr = (uchar *)(shmat(shmid, nullptr, SHM_RDONLY));
+                if (shmaddr == (uchar *)-1) {
+                    shmctl(shmid, IPC_RMID, nullptr);
+                    shmaddr = nullptr;
+                    shmid = -1;
                 }
             }
         }
-        if (shmid != -1) {
-            job->addMetaData(QStringLiteral("shmid"), QString::number(shmid));
-        }
-#endif
     }
+    if (shmid != -1) {
+        job->addMetaData(QStringLiteral("shmid"), QString::number(shmid));
+    }
+#endif
 }
 
 void PreviewJobPrivate::slotStandardThumbData(KIO::Job *job, const QImage &thumbData)
