@@ -18,8 +18,8 @@ public:
 };
 
 KSslCertificateBox::KSslCertificateBox(QWidget *parent)
-    : QWidget(parent),
-      d(new KSslCertificateBoxPrivate())
+    : QWidget(parent)
+    , d(new KSslCertificateBoxPrivate())
 {
     d->ui.setupUi(this);
     // No fooling us with html tags
@@ -29,26 +29,21 @@ KSslCertificateBox::KSslCertificateBox(QWidget *parent)
     }
 }
 
-KSslCertificateBox::~KSslCertificateBox()
-{
-    delete d;
-}
+KSslCertificateBox::~KSslCertificateBox() = default;
 
 void KSslCertificateBox::setCertificate(const QSslCertificate &cert, CertificateParty party)
 {
-    if (party == Subject)  {
+    if (party == Subject) {
         d->ui.commonName->setText(cert.subjectInfo(QSslCertificate::CommonName).join(QLatin1String(", ")));
         d->ui.organization->setText(cert.subjectInfo(QSslCertificate::Organization).join(QLatin1String(", ")));
-        d->ui.organizationalUnit
-        ->setText(cert.subjectInfo(QSslCertificate::OrganizationalUnitName).join(QLatin1String(", ")));
+        d->ui.organizationalUnit->setText(cert.subjectInfo(QSslCertificate::OrganizationalUnitName).join(QLatin1String(", ")));
         d->ui.country->setText(cert.subjectInfo(QSslCertificate::CountryName).join(QLatin1String(", ")));
         d->ui.state->setText(cert.subjectInfo(QSslCertificate::StateOrProvinceName).join(QLatin1String(", ")));
         d->ui.city->setText(cert.subjectInfo(QSslCertificate::LocalityName).join(QLatin1String(", ")));
     } else if (party == Issuer) {
         d->ui.commonName->setText(cert.issuerInfo(QSslCertificate::CommonName).join(QLatin1String(", ")));
         d->ui.organization->setText(cert.issuerInfo(QSslCertificate::Organization).join(QLatin1String(", ")));
-        d->ui.organizationalUnit
-        ->setText(cert.issuerInfo(QSslCertificate::OrganizationalUnitName).join(QLatin1String(", ")));
+        d->ui.organizationalUnit->setText(cert.issuerInfo(QSslCertificate::OrganizationalUnitName).join(QLatin1String(", ")));
         d->ui.country->setText(cert.issuerInfo(QSslCertificate::CountryName).join(QLatin1String(", ")));
         d->ui.state->setText(cert.issuerInfo(QSslCertificate::StateOrProvinceName).join(QLatin1String(", ")));
         d->ui.city->setText(cert.issuerInfo(QSslCertificate::LocalityName).join(QLatin1String(", ")));
@@ -65,3 +60,4 @@ void KSslCertificateBox::clear()
     d->ui.city->clear();
 }
 
+#include "moc_ksslcertificatebox.cpp"
